SystemOrganization addCategory: #Deli!
SystemOrganization addCategory: #'Deli-models'!
SystemOrganization addCategory: #'Deli-configuration'!
SystemOrganization addCategory: #'Deli-models-tests'!
SystemOrganization addCategory: #'Deli-frontend'!
SystemOrganization addCategory: #'Deli-frontend-util'!

WAFileLibrary subclass: #DLFileLibrary
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLFileLibrary methodsFor: 'as yet unclassified' stamp: 'cr 6/1/2009 01:16'!
selectorsToInclude

	^ Array with: 'styleCss'! !

!DLFileLibrary methodsFor: 'uploaded' stamp: 'cr 6/1/2009 01:25'!
styleCss
	^
'.menu {
	float: left;
	width: 250px;
	padding: 10px;
}

thead>td {
	font-weight: bold;
}
'! !

!DLFileLibrary methodsFor: 'as yet unclassified' stamp: 'cr 6/1/2009 01:14'!
updateRoot:	anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot stylesheet url: DLFileLibrary / #styleCss.! !

SqsTestCase subclass: #DLDeliTestCase
	instanceVariableNames: 'semester lecture user membership group'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

DLDeliTestCase subclass: #DLDeadlineTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

!DLDeliTestCase methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 10:37'!
fixture
	"We assume that creation through the orm works."
	| userJack userJohn |
	semester := DLSemester new
		semesterName: 'Winter';
		year: 2009;
		save.
	
	lecture := DLLecture new
		lectureName: 'Softwaretechnik I';
		lectureDescription: 'An introduction to techniques in software development';
		semester: semester;
		save.
	
	user := DLUser new
		userName: 'john';
		save.
	
	userJack := DLUser createUserName: 'jack' email: 'jack@student.hpi.uni-potsdam.de'.
	userJohn := DLUser createFrom: {#userName->'john'. #email->'john@hpi.uni-potsdam.de'. #isAdmin->true}.
	
	
	membership := DLLectureMembership new
		user: user;
		lecture: lecture;
		role: #student;
		save.

	group := DLGroup new
		groupName: 'Roundup porns';
		groupDescription: 'Roundup in awesome';
		lecture: lecture;
		users: ( {user} as: OrderedCollection );
		save.! !

!DLDeliTestCase methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 09:50'!
setUp
	| session |
	super setUp.
	session := SqsConnectionManager getInstance sessionForClass: DLLecture.
	session resetDatabase.
	self fixture.
	"session beginTransaction."

! !

!DLDeliTestCase methodsFor: 'as yet unclassified' stamp: 'sebh 5/20/2009 19:35'!
tearDown
	| session |
	super tearDown.
	
	"""session := SqsConnectionManager getInstance sessionForClass: DLLecture.
	session rollbackTransaction."""
! !

DLDeliTestCase subclass: #DLGeneralTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

!DLGeneralTests methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 13:01'!
testCreate
	
	| aUser bUser |
	aUser := DLUser createFrom: {#userName->'dylan'. #email->'dylan@myhpi.com'. #isAdmin->'true'}.
	
	self assert: ((SqsSearch for: DLUser) detect: [:anUser | anUser userName = 'dylan'] ifNone: [nil]) notNil.
	
	bUser := DLUser getOrCreateFrom: {#userName->'dylan'}.
	
	self assert: aUser equals: bUser.! !

DLDeliTestCase subclass: #DLLectureMembershipTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

!DLLectureMembershipTest methodsFor: 'as yet unclassified' stamp: 'Marik 5/26/2009 17:55'!
testUniqueMemberships
	| aNotAllowedMembership |
	aNotAllowedMembership := DLLectureMembership withLecture: lecture user: user role: #teacher.
	self assert: [aNotAllowedMembership isNil] description: 'A second membership on the same person should not be created.'.
	
	membership destroy.
	membership := DLLectureMembership withLecture: lecture user: user role: #teacher.
	
	self assert: [ membership notNil] description: 'A membership can be created after the other membership was deleted.'.
! !

DLDeliTestCase subclass: #DLLectureTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

DLDeliTestCase subclass: #DLSemesterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

Object subclass: #DLLoginUser
	instanceVariableNames: 'userName password'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLLoginUser methodsFor: 'accessing-generated' stamp: 'sebh 5/27/2009 12:03'!
password
	^ password! !

!DLLoginUser methodsFor: 'accessing-generated' stamp: 'sebh 5/27/2009 12:03'!
userName
	^ userName! !

Object subclass: #DLModel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

DLModel subclass: #DLLecture
	instanceVariableNames: 'semester lectureName teacherName assistentName lectureDescription groupSize groups'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'Marik 5/27/2009 15:42'!
createLectureName: aLectureName semester: aSemester description: aDescription
	^ self new
		lectureName: aLectureName;
		semester: aSemester;
		description: aDescription;
		save;
		yourself.! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionAssistentName
	^ (MAMemoDescription auto: 'assistentName' label: 'Assistenten' priority: 40)
			yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionGroupSize
	^ (MANumberDescription auto: 'groupSize' label: 'Gruppengre' priority: 60)
			yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionLectureDescription
	^ (MAMemoDescription auto: 'lectureDescription' label: 'Beschreibung' priority: 20)
			yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionLectureName
	^ (MAStringDescription auto: 'lectureName' label: 'Lehrveranstaltung' priority: 10)
			beRequired;
			yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 20:28'!
descriptionSemester
	^ (MASingleOptionDescription auto: 'semester' label: 'Semester' priority: 50)
			options: #( 'SoSe 09' 'WiSe 09/10' 'SoSe 10' 'WiSe 10/11' 'SoSe 11');
			beRequired;
			reference: MAStringDescription new;
			yourself.! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionTeacherName
	^ (MAStringDescription auto: 'teacherName' label: 'Dozent' priority: 30)
			beRequired;
			yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionVisible
"	^ MABooleanDescription new
			accessor: #lectureVisibility;
			label: 'visible';
			componentClass: MACheckboxComponent;
			yourself.
"! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'Marik 5/27/2009 15:47'!
getOrCreateUserName: aLectureName semester: aSemester description: aDescription

	| lecture |
	lecture := (SqsSearch for: self) detect: [:aLecture | 
		(aLecture lectureName = aLectureName) & (aLecture semester = aSemester)]
	                                 ifNone: [nil].
	lecture ifNotNil: [ ^ lecture ].
	^ self createLectureName: aLectureName semester: aSemester description: aDescription.
! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLectureDescription
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'lecture_description';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lectureDescription';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLectureName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'lecture_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lectureName';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrSemester
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'semester';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'semester';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrTeacherName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'teacher_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'teacherName';
		 yourself! !

!DLLecture methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:02'!
assistentName

	^ assistentName! !

!DLLecture methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:02'!
assistentName: anObject

	assistentName := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:02'!
groupSize

	^ groupSize! !

!DLLecture methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:02'!
groupSize: anObject

	groupSize := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:20'!
groups

	^ groups! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:20'!
groups: anObject

	groups := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:30'!
initialize
	super initialize.
	self groups: OrderedCollection new.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:23'!
lectureDescription

	^ lectureDescription! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:23'!
lectureDescription: anObject

	lectureDescription := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
lectureName

	^ lectureName! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
lectureName: anObject

	lectureName := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
semester

	^ semester! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
semester: anObject

	semester := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:02'!
teacherName

	^ teacherName! !

!DLLecture methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:02'!
teacherName: anObject

	teacherName := anObject.! !

!DLModel class methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 14:46'!
createFrom: anArray
	"Create an object with the values given in anArray and use the standard getters/setters so nondefault get/set behaviour works"
	| newobject |
	newobject := self new.
	anArray do: [:element | newobject perform: (element key, ':') asSymbol withArguments: (Array with: element value) ].
	newobject save.
	^ newobject
	! !

!DLModel class methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 14:44'!
getOrCreateFrom: anAttributeArray
	"Get an object from a given attribute array, create one if it doesn't exist yet.'"
	| objects keys values |
	keys := anAttributeArray collect: [:anAttribute | anAttribute key].
	values := anAttributeArray collect: [:anAttribute | anAttribute value].
	objects := (SqsSearch for: self) searchBy: keys withValues: values limit:2.
	
	objects size > 1
	ifTrue: [ ^ nil "TODO: Replace this with an exception stating that there is more than one object"].
	objects size = 1
	ifTrue: [ ^ objects at: 1 ]
	ifFalse:[ ^ self createFrom: anAttributeArray ].! !

!DLModel class methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 10:24'!
sqsAbstractBaseClass! !

DLModel subclass: #DLSemester
	instanceVariableNames: 'semesterName year'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLSemester class methodsFor: 'persistence-description' stamp: ''!
sqsDescrSemesterName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'semester_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_semesters';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'semesterName';
		 yourself! !

!DLSemester class methodsFor: 'persistence-description' stamp: ''!
sqsDescrYear
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'year';
		 sqlType: #integer;
		 objectClass: #SmallInteger;
		 tableName: 'dl_semesters';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'year';
		 yourself! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/27/2009 22:52'!
canonicalName
	^ self semesterName, self year asString.! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
semesterName

	^ semesterName! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
semesterName: anObject

	semesterName := anObject.! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
year

	^ year! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
year: anObject

	year := anObject.! !

DLModel subclass: #DLUser
	instanceVariableNames: 'userName email isAdmin'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLUser class methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 13:30'!
createUserName: aUserName email: aEmail
	^ self new
		userName: aUserName;
		email: aEmail;
		save;
		yourself.! !

!DLUser class methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 13:56'!
getOrCreateUserName: aUserName email: aEmail
	| user |
	user := (SqsSearch for: self) detect: [:aUser | (aUser userName = aUserName)] ifNone: [nil].
	user ifNotNil: [ ^ user ].
	^ self createUserName: aUserName email: aEmail.
! !

!DLUser class methodsFor: 'persistence-description' stamp: 'Marik 5/27/2009 10:23'!
sqsDescrEmail
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'email';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_users';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'email';
		 yourself! !

!DLUser class methodsFor: 'persistence-description' stamp: ''!
sqsDescrIsAdmin
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'is_admin';
		 sqlType: #boolean;
		 objectClass: #False;
		 tableName: 'dl_users';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'isAdmin';
		 yourself! !

!DLUser class methodsFor: 'persistence-description' stamp: 'Marik 5/27/2009 10:24'!
sqsDescrUserName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'user_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_users';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'userName';
		 yourself! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/27/2009 10:17'!
email

	^ email! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/27/2009 10:17'!
email: anObject

	email := anObject.! !

!DLUser methodsFor: 'accessing' stamp: 'sebh 5/28/2009 14:09'!
initialize
	super initialize.
	self isAdmin: false.! !

!DLUser methodsFor: 'accessing' stamp: 'sebh 5/27/2009 23:08'!
isAdmin

	^ isAdmin! !

!DLUser methodsFor: 'accessing' stamp: 'sebh 5/27/2009 23:08'!
isAdmin: anObject

	isAdmin := anObject.! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/26/2009 13:25'!
userName

	^ userName! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/26/2009 13:25'!
userName: anObject

	userName := anObject.! !

Object subclass: #DLTest
	instanceVariableNames: 'tmp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLTest methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 13:49'!
initialize
	tmp := MAContainer with: DLLoginUser descriptionLectureName.! !

!DLTest methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 13:47'!
renderContentOn: html
	! !

!DLTest methodsFor: 'accessing' stamp: 'cr 5/31/2009 13:50'!
tmp

	^ tmp! !

!DLTest methodsFor: 'accessing' stamp: 'cr 5/31/2009 13:50'!
tmp: anObject

	tmp := anObject.! !

Object subclass: #Tutorials
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli'!

!Tutorials methodsFor: 'as yet unclassified' stamp: 'Marik 5/19/2009 17:41'!
HowToUseHPILogin

"
--> Load LDAPlayer v47 via SqueakMapPackageLoader
--> Load HPILogin class via Monticello from Repository http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/HPILogin

--> Use

hpi := HPILoginChecker new.
hpi checkLogin: 'surname.name' password: '******'"! !

WATask subclass: #DLRootTask
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLRootTask class methodsFor: 'testing' stamp: 'Marik 5/26/2009 13:30'!
canBeRoot

	^true! !

!DLRootTask methodsFor: 'processing' stamp: 'MG 5/27/2009 20:35'!
go

	self loginUser.! !

!DLRootTask methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 18:15'!
loginUser

	| loginAnswer |
	
	loginAnswer := self call: DLLoginComp new.
	loginAnswer
		ifNotNil: [self session login: loginAnswer].
	
	self call: DLDashComp new.! !

WATask subclass: #DLTestRootTask
	instanceVariableNames: 'test'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLTestRootTask class methodsFor: 'testing' stamp: 'sebh 5/27/2009 11:57'!
canBeRoot

	^true! !

!DLTestRootTask methodsFor: 'processing' stamp: 'cr 5/31/2009 14:02'!
go

	|loginAnswer userComp loginUser |
	loginUser := DLLoginUser new.
	userComp := loginUser description asComponentOn: loginUser.
	userComp addValidatedForm.
	 
	loginAnswer := self call: userComp .
	loginAnswer
		ifNotNil: [
			self session login: loginAnswer.
			self call: DLDashComp new]
		ifNil: [
			
			]! !

!DLTestRootTask methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 14:01'!
initialize
	super initialize.
	"self test: MAContainerComponent new. "! !

WAComponent subclass: #DLComponent
	instanceVariableNames: 'menuComp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLComponent methodsFor: 'accessing' stamp: 'sebh 5/27/2009 23:07'!
accessCheck
	^ self session user isAdmin! !

!DLComponent methodsFor: 'accessing' stamp: 'sebh 5/27/2009 23:01'!
menuComp

	^ menuComp! !

!DLComponent methodsFor: 'accessing' stamp: 'sebh 5/27/2009 23:01'!
menuComp: anObject

	menuComp := anObject.! !

!DLComponent methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 14:47'!
renderContent: html
	self subclassResponsibility! !

!DLComponent methodsFor: 'accessing' stamp: 'sebh 5/28/2009 11:32'!
renderContentOn: html
	html heading: 'Deli';
		  heading: 'Abgabensystem';
		break.
	self session isLoggedIn
		ifTrue: 	[self renderLoggedIn: html]
		ifFalse: [self renderDeny:		 html]! !

!DLComponent methodsFor: 'rendering' stamp: 'sebh 5/27/2009 23:05'!
renderDeny: html

	html text: 'Sie sind hier nicht willkommen!!'! !

!DLComponent methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 23:05'!
renderLoggedIn: html
	self renderMenu: html.
	self renderContent: html.
! !

!DLComponent methodsFor: 'accessing' stamp: 'sebh 5/27/2009 23:06'!
renderMenu: html
	html div class: 'menu';
		with: self menuComp.! !

DLComponent subclass: #DLDashComp
	instanceVariableNames: 'lectureMembershipComp overviewComp lectureFormComp lectureListComp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLDashComp methodsFor: 'accessing' stamp: 'sebh 5/28/2009 12:44'!
children
	^ Array with: self menuComp with: self overviewComp.! !

!DLDashComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 18:44'!
createNewLecture
	self overviewComp: lectureFormComp.
	self lectureFormComp createNewLecture.! !

!DLDashComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 21:27'!
editLecture: aLecture
	self overviewComp: lectureFormComp.
	self lectureFormComp editLecture: aLecture! !

!DLDashComp methodsFor: 'rendering' stamp: 'cr 5/31/2009 21:26'!
initialize
	super initialize.
	
	self
		menuComp:
			(DLAdminMenuComp withContent: self);
		lectureMembershipComp:
			DLLectureMembershipListComp new;
		lectureFormComp:
			DLLectureFormComp new;
		lectureListComp:
			DLLectureListComp new.
	self lectureListComp
		lectureFormComp: self lectureFormComp;
		dashComp: self.
		! !

!DLDashComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 18:17'!
lectureFormComp

	^ lectureFormComp! !

!DLDashComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 18:17'!
lectureFormComp: anObject

	lectureFormComp := anObject.! !

!DLDashComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 19:08'!
lectureListComp

	^ lectureListComp! !

!DLDashComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 19:08'!
lectureListComp: anObject

	lectureListComp := anObject.! !

!DLDashComp methodsFor: 'accessing' stamp: 'MG 5/27/2009 20:45'!
lectureMembershipComp

	^ lectureMembershipComp! !

!DLDashComp methodsFor: 'accessing' stamp: 'MG 5/27/2009 20:45'!
lectureMembershipComp: anObject

	lectureMembershipComp := anObject.! !

!DLDashComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 19:08'!
listCurrentLectures
	self overviewComp: lectureListComp.! !

!DLDashComp methodsFor: 'accessing' stamp: 'MG 5/27/2009 19:54'!
overviewComp

	^ overviewComp! !

!DLDashComp methodsFor: 'accessing' stamp: 'MG 5/27/2009 19:54'!
overviewComp: anObject

	overviewComp := anObject.! !

!DLDashComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 18:43'!
renderContent: html

	html div class: 'content';
				with: self overviewComp.! !

DLComponent subclass: #DLLectureDetailComp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

DLComponent subclass: #DLLectureListComp
	instanceVariableNames: 'dashComp lectureFormComp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLectureListComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 21:15'!
dashComp

	^ dashComp! !

!DLLectureListComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 21:15'!
dashComp: anObject

	dashComp := anObject.! !

!DLLectureListComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 20:53'!
lectureFormComp

	^ lectureFormComp! !

!DLLectureListComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 20:53'!
lectureFormComp: anObject

	lectureFormComp := anObject.! !

!DLLectureListComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 21:29'!
renderContentOn: html
	| lectures |
	lectures := (SqsSearch for: DLLecture) findAll.
	html table: [
		html tableHead: [
			html
				tableRow: [	
						html
							tableData: [html text: 'Name'];
							tableData: [html text: 'Dozent'];
							tableData: [html text: 'Beschreibung'];
							tableData: [html text: 'Semester'];
							tableData: [html text: 'Gruppengre'];
							tableData: [html text: 'Mitarbeiter'];
							tableData: [html text: 'Aktionen']
					]
			].
		lectures do: [:aLecture |
			html
				tableRow: [
					html
						tableData: [html text: aLecture lectureName];
						tableData: [html text: aLecture teacherName];
						tableData: [html text: aLecture lectureDescription];
						tableData: [html text: aLecture semester];
						tableData: [html text: aLecture groupSize];
						tableData: [html text: aLecture assistentName];
						tableData: [html anchor callback: [ self dashComp editLecture: aLecture ]; with: 'Bearbeiten']
					]	
				]
		]
	"html unorderedList 
		with: [
			lectures do: [:aLecture |
				html listItem
					with: [
						html heading: aLecture lectureName;
							  text:  out of scope ->aLecture semester canonicalName;
							  text: aLecture lectureDescription.
					]
			]
	  
		]."! !

WAComponent subclass: #DLLectureFormComp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 19:04'!
createNewLecture
	|lecture editor|
	editor := self getEditor.

	lecture:= self call: editor.

	lecture 	
		ifNotNil:[lecture save]
		ifNil:[Exception new]! !

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 20:56'!
editLecture: aLecture
	|lecture editor|
	editor := self getEditorForLecture: aLecture.

	lecture:= self call: editor.

	lecture 	
		ifNotNil:[lecture save]
		ifNil:[Exception new]! !

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 20:50'!
getEditor
	^DLLecture new asComponent addValidatedForm.! !

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 21:05'!
getEditorForLecture: aLecture
	^(aLecture asComponent) addValidatedForm.! !

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 19:03'!
renderContent: html
	html text: 'when does this happen?'! !

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 19:05'!
renderContentOn: html
	html text: 'when does this happen?'! !

WAComponent subclass: #DLLectureMembershipListComp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLectureMembershipListComp methodsFor: 'rendering' stamp: 'MG 5/27/2009 20:56'!
renderContentOn: html
	
	html text: 'Lehrveranstaltungen, die du besuchst:';
		  break.
	self renderLectureMemberships: html;
		  answer: true.! !

!DLLectureMembershipListComp methodsFor: 'rendering' stamp: 'MG 5/27/2009 20:08'!
renderLectureMemberships: html

	| lectureMemberships currentUser |
	
	currentUser := self session user.
	lectureMemberships := (SqsSearch for: DLLectureMembership) select:[:aLectureMembership | 
		aLectureMembership user = currentUser].
	lectureMemberships do:[:aLectureMembership |
		html text: aLectureMembership lecture lectureName;
			  break]! !

WAComponent subclass: #DLLoginComp
	instanceVariableNames: 'userName password'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLoginComp methodsFor: 'computing' stamp: 'sebh 5/27/2009 13:47'!
acceptUser

	|user|
	user := DLUser getOrCreateUserName: self userName email: userName, '@student.hpi.uni-potsdam.de'.
	self 	clearUserData;
			answer: user! !

!DLLoginComp methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:16'!
clearUserData

	self 	userName: nil;
			password: nil! !

!DLLoginComp methodsFor: 'computing' stamp: 'Marik 5/20/2009 16:56'!
denyUser

	self 	clearUserData;
			answer: nil! !

!DLLoginComp methodsFor: 'accessing' stamp: 'Marik 5/20/2009 16:30'!
password

	^ password! !

!DLLoginComp methodsFor: 'accessing' stamp: 'Marik 5/20/2009 16:30'!
password: anObject

	password := anObject.! !

!DLLoginComp methodsFor: 'rendering' stamp: 'sebh 5/26/2009 23:21'!
renderContentOn: html

	html heading: 'Deli login'.
	html 
		form id: 'loginForm';
	   with: [
			html table: [
				html tableRow: [self renderNameInputOn: html];
					  tableRow: [self renderPasswordInputOn: html];
					  tableRow: [self renderSubmitButtonOn: html]
			]
		].! !

!DLLoginComp methodsFor: 'rendering' stamp: 'Marik 5/26/2009 18:29'!
renderNameInputOn: html

	html 	tableData: [html text: 'Name: '];
			tableData: [html textInput id: 'userName';
	                                 on: #userName of: self]! !

!DLLoginComp methodsFor: 'rendering' stamp: 'Marik 5/27/2009 14:49'!
renderPasswordInputOn: html

	html 	tableData: [html text: 'Password: '];
			tableData: [html passwordInput id: 'password';
	                                     on: #password of: self]! !

!DLLoginComp methodsFor: 'rendering' stamp: 'Marik 5/20/2009 16:41'!
renderSubmitButtonOn: html

	html tableData: [html submitButton 	callback:[self validateLogin];
													text: 'Login']
! !

!DLLoginComp methodsFor: 'as yet unclassified' stamp: 'MG 5/27/2009 20:39'!
resetOldSession

	(self session user notNil)
		ifTrue: [self session expire].! !

!DLLoginComp methodsFor: 'accessing' stamp: 'Marik 5/20/2009 16:30'!
userName

	^ userName! !

!DLLoginComp methodsFor: 'accessing' stamp: 'Marik 5/20/2009 16:30'!
userName: anObject

	userName := anObject.! !

!DLLoginComp methodsFor: 'computing' stamp: 'cr 5/31/2009 14:44'!
validateLogin

	|loginChecker|
	
	self resetOldSession.
	
	"A test user so we don't need to have hpi nads2 present all the time"
	(self userName = 'john') | (self userName = 'jack')
		ifTrue: [self acceptUser].
	"A bad test user"
	self userName =  'christian'
		ifTrue: [self denyUser].
	
	loginChecker := HPILoginChecker new.
	(loginChecker checkLogin: self userName password: self password)
		ifTrue:[self acceptUser]
		ifFalse:[self denyUser]! !

WAComponent subclass: #DLMenuComp
	instanceVariableNames: 'entries content'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend-util'!

DLMenuComp subclass: #DLAdminMenuComp
	instanceVariableNames: 'lectureListComp formComponent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend-util'!

!DLAdminMenuComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 18:45'!
addEntries
	self entries
		add: 'Lehrveranstaltungen' -> {
			       'Aktuelle Lehrveranstaltungen' -> [ self content listCurrentLectures ].
					 'Alte Lehrveranstaltungen'-> [].
					 'Neue Lehrveranstaltung anlegen' -> [ self content createNewLecture ].
			   };
		add: 'Andere Aktionen' -> { 'Ausloggen' -> [] }.
! !

!DLAdminMenuComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 15:41'!
children
	^ Array with: formComponent.! !

!DLAdminMenuComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:23'!
formComponent

	^ formComponent! !

!DLAdminMenuComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:23'!
formComponent: anObject

	formComponent := anObject.! !

!DLAdminMenuComp methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:26'!
initialize
	super initialize.
	self formComponent: DLLectureFormComp new! !

!DLAdminMenuComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:23'!
lectureListComp

	^ lectureListComp! !

!DLAdminMenuComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:23'!
lectureListComp: anObject

	lectureListComp := anObject.! !

!DLAdminMenuComp methodsFor: 'rendering' stamp: ''!
style ^ 'float: left;'! !

!DLMenuComp class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 18:23'!
withContent: aComponent
	^self new content: aComponent;
		yourself.! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 15:27'!
addEntries
	"If an inheriting method has defined this method, we use it to automagically insert entries"! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/26/2009 17:12'!
addEntry: aString withAction: aBlock
	
	^ self entries add: aString -> aBlock! !

!DLMenuComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 18:21'!
content

	^ content! !

!DLMenuComp methodsFor: 'accessing' stamp: 'cr 5/31/2009 18:21'!
content: anObject

	content := anObject.! !

!DLMenuComp methodsFor: 'accessing' stamp: 'sebh 5/26/2009 17:08'!
entries

	^ entries! !

!DLMenuComp methodsFor: 'accessing' stamp: 'sebh 5/26/2009 17:08'!
entries: anObject

	entries := anObject.! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 15:26'!
initialize
	super initialize.
	self entries: OrderedCollection new.
	self addEntries.! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 15:42'!
renderContentOn: html

	self entries
		do: [:entry | self renderEntry: entry on: html. ]
		separatedBy: [html break].! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 15:50'!
renderEntry: anEntry on: html
	self renderEntry: anEntry on: html level: 2 ! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 12:45'!
renderEntry: anEntry on: html level: aLevel
	anEntry value isCollection
	ifTrue: [ 
		html heading: anEntry key level: aLevel.
		anEntry value do: [:entry | self renderEntry: entry on: html level: aLevel+1] separatedBy: [html break].
	]
	ifFalse: [
		html anchor
			callback: anEntry value;
			with: anEntry key.
	].! !

SqsSearchInterface subclass: #DLDeadline
	instanceVariableNames: 'deadlineName description date'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
date

	^ date! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
date: anObject

	date := anObject.! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
deadlineName

	^ deadlineName! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
deadlineName: anObject

	deadlineName := anObject.! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
description

	^ description! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
description: anObject

	description := anObject.! !

SqsSearchInterface subclass: #DLGroup
	instanceVariableNames: 'groupName groupDescription lecture users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrDescription
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'description';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'description';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrGroupDescription
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'group_description';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'groupDescription';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrGroupName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'group_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'groupName';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLecture
	^ SqsColumn new associatedClass: #DLLecture;
		 manuallyMaintained: false;
		 columnName: 'lecture_id';
		 sqlType: #integer;
		 objectClass: #DLLecture;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lecture';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUsers
	^ SqsCollectionDescription new manuallyMaintained: false;
		 collectionClass: #OrderedCollection;
		 tableName: 'dl_groups_users';
		 ownerColumn: (SqsColumn basicNew instVarAt: 1 put: nil;
			 instVarAt: 2 put: false;
			 instVarAt: 3 put: 'dl_group_id';
			 instVarAt: 4 put: #integer;
			 instVarAt: 5 put: nil;
			 instVarAt: 6 put: nil;
			 instVarAt: 7 put: (SqsForeignKeyDescription new manuallyMaintained: false;
				 referencedColumns: (Set new add: 'id';
					 yourself);
				 referencedTable: 'dl_groups';
				 updateActions: #();
				 deleteActions: (OrderedCollection new add: #CASCADE;
					 yourself);
				 referencingColumns: (Set new add: 'dl_group_id';
					 yourself);
				 yourself);
			 instVarAt: 8 put: false;
			 instVarAt: 9 put: false;
			 instVarAt: 10 put: false;
			 instVarAt: 11 put: #SQSOWNER;
			 yourself);
		 referenceColumn: (SqsColumn basicNew instVarAt: 1 put: nil;
			 instVarAt: 2 put: false;
			 instVarAt: 3 put: 'users_id';
			 instVarAt: 4 put: #integer;
			 instVarAt: 5 put: nil;
			 instVarAt: 6 put: nil;
			 instVarAt: 7 put: (SqsForeignKeyDescription new manuallyMaintained: false;
				 referencedColumns: (Set new add: 'id';
					 yourself);
				 referencedTable: 'dl_users';
				 updateActions: #();
				 deleteActions: #(#CASCADE );
				 referencingColumns: (Set new add: 'users_id';
					 yourself);
				 yourself);
			 instVarAt: 8 put: false;
			 instVarAt: 9 put: false;
			 instVarAt: 10 put: false;
			 instVarAt: 11 put: #SQSREF;
			 yourself);
		 maintainOrder: true;
		 simpleValues: false;
		 indexType: #integer;
		 referencedClass: #DLUser;
		 linkedVariable: 'users';
		 orderField: 'sqs_order_number';
		 yourself! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:27'!
groupDescription

	^ groupDescription! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:27'!
groupDescription: anObject

	groupDescription := anObject.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:54'!
groupName

	^ groupName! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:54'!
groupName: anObject

	groupName := anObject.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 12:00'!
initialize
	super initialize.
	self users: OrderedCollection new.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
lecture

	^ lecture! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
lecture: anObject

	lecture := anObject.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
users

	^ users! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
users: anObject

	users := anObject.! !

SqsSearchInterface subclass: #DLLectureMembership
	instanceVariableNames: 'lecture user role'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLLectureMembership class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLecture
	^ SqsColumn new associatedClass: #DLLecture;
		 manuallyMaintained: false;
		 columnName: 'lecture_id';
		 sqlType: #integer;
		 objectClass: #DLLecture;
		 tableName: 'dl_lecture_memberships';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lecture';
		 yourself! !

!DLLectureMembership class methodsFor: 'persistence-description' stamp: ''!
sqsDescrRole
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'role';
		 sqlType: #string;
		 objectClass: #ByteSymbol;
		 tableName: 'dl_lecture_memberships';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'role';
		 yourself! !

!DLLectureMembership class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUser
	^ SqsColumn new associatedClass: #DLUser;
		 manuallyMaintained: false;
		 columnName: 'user_id';
		 sqlType: #integer;
		 objectClass: #DLUser;
		 tableName: 'dl_lecture_memberships';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'user';
		 yourself! !

!DLLectureMembership class methodsFor: 'as yet unclassified' stamp: 'sebh 5/26/2009 09:20'!
withLecture: aLecture user: aUser role: aRole
	
	| memberships |
	memberships := 
	(SqsSearch for: self) detect: [:aMembership | (aMembership lecture = aLecture) & (aMembership user = aUser)] ifNone: [nil].
	
	memberships ifNotNil: [ ^ nil ].
	
	^ self new
		lecture: aLecture;
		user: aUser;
		role: aRole;
		save;
		yourself.! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
lecture

	^ lecture! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
lecture: anObject

	lecture := anObject.! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:05'!
role

	^ role! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:05'!
role: anObject

	role := anObject.! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
user

	^ user! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
user: anObject

	user := anObject.! !

SqsSearchInterface subclass: #DLUpdateModel
	instanceVariableNames: 'created updated'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLUpdateModel class methodsFor: 'persistence-description' stamp: ''!
sqsDescrCreated
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'created';
		 sqlType: #dateAndTime;
		 objectClass: #DateAndTime;
		 tableName: 'dl_update_models';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'created';
		 yourself! !

!DLUpdateModel class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUpdated
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'updated';
		 sqlType: #dateAndTime;
		 objectClass: #DateAndTime;
		 tableName: 'dl_update_models';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'updated';
		 yourself! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
created

	^ created! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
created: anObject

	created := anObject.! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:06'!
initialize
	self created: DateAndTime now.! !

!DLUpdateModel methodsFor: 'as yet unclassified' stamp: 'sebh 5/20/2009 19:06'!
save
	self updated: DateAndTime now.
	super save! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
updated

	^ updated! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
updated: anObject

	updated := anObject.! !

WASession subclass: #DLSession
	instanceVariableNames: 'user'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLSession methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:09'!
isLoggedIn

	^self user isNil not! !

!DLSession methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:09'!
login: aUser

	self user: aUser! !

!DLSession methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:09'!
logout

	self user: nil.! !

!DLSession methodsFor: 'accessing' stamp: 'Marik 5/20/2009 17:08'!
user

	^ user! !

!DLSession methodsFor: 'accessing' stamp: 'Marik 5/20/2009 17:08'!
user: anObject

	user := anObject.! !

SqsConfig subclass: #DeliSqsConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-configuration'!

!DeliSqsConfig class methodsFor: 'as yet unclassified' stamp: 'sebh 5/20/2009 16:13'!
connectionSpecification
	^ SqsMySQLConnectionSpecification 
		user: 'deli'
		password: ''
		database: 'deli'
		port: 3306
		host: 'localhost'! !
